multiformats.multibase.err
==========================

.. automodule:: multiformats.multibase.err

MultibaseKeyError
-----------------

.. autoclass:: multiformats.multibase.err.MultibaseKeyError
    :members:

MultibaseValueError
-------------------

.. autoclass:: multiformats.multibase.err.MultibaseValueError
    :members:
